import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import { lighten, makeStyles } from '@material-ui/core/styles';
import Table from '@material-ui/core/Table';
import TableBody from '@material-ui/core/TableBody';
import TableCell from '@material-ui/core/TableCell';
import TableContainer from '@material-ui/core/TableContainer';
import TableHead from '@material-ui/core/TableHead';
import TablePagination from '@material-ui/core/TablePagination';
import TableRow from '@material-ui/core/TableRow';
import TableSortLabel from '@material-ui/core/TableSortLabel';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import './table.css';
import "bootstrap/dist/css/bootstrap.min.css";
import "react-stepzilla/src/css/main.css";
import './assets/css/moh-style.css';
import "./assets/css/icon-style.css";
import './assets/css/App.css';
import "./assets/plugin/font-awesome/css/font-awesome.min.css";

function desc(a, b, orderBy) {
  if (b[orderBy] < a[orderBy]) {
    return -1;
  }

  if (b[orderBy] > a[orderBy]) {
    return 1;
  }

  return 0;
}

function stableSort(array, cmp) {
  const stabilizedThis = array.map((el, index) => [el, index]);
  stabilizedThis.sort((a, b) => {
    const order = cmp(a[0], b[0]);
    if (order !== 0) return order;
    return a[1] - b[1];
  });
  return stabilizedThis.map(el => el[0]);
}

function getSorting(order, orderBy) {
  return order === 'desc' ? (a, b) => desc(a, b, orderBy) : (a, b) => -desc(a, b, orderBy);
}

function buildHeader(rowHeader, filterColumns) {
  // const filteredColumn = []
  // rowHeader.map(function(item, i){
  //   if((filterColumns.indexOf(item.name) > -1) ===  true){
  //     filteredColumn.push(item)
  //   } 
  // })
  //return filteredColumn
  return rowHeader;
}

function EnhancedTableHead(props) {
  const {
    classes,
    order,
    orderBy,
    onRequestSort,
    rowHeader,
    filterColumns
  } = props;

  const createSortHandler = property => event => {
    onRequestSort(event, property);
  };

  const filteredColumn = buildHeader(rowHeader, filterColumns);
  return /*#__PURE__*/React.createElement(TableHead, null, /*#__PURE__*/React.createElement(TableRow, null, filteredColumn.map((headCell, hkey) => /*#__PURE__*/React.createElement(TableCell, {
    key: headCell.name + hkey,
    align: headCell.numeric ? 'right' : 'left',
    padding: headCell.disablePadding ? 'none' : 'default',
    sortDirection: orderBy === headCell.name ? order : false
  }, /*#__PURE__*/React.createElement(TableSortLabel, {
    active: orderBy === headCell.name,
    direction: orderBy === headCell.name ? order : 'asc',
    onClick: createSortHandler(headCell.name)
  }, headCell.label, orderBy === headCell.name ? /*#__PURE__*/React.createElement("span", {
    className: classes.visuallyHidden
  }, order === 'desc' ? 'sorted descending' : 'sorted ascending') : null))), props.deleteEnable === true || props.viewEnable === true ? /*#__PURE__*/React.createElement(TableCell, {
    key: "action",
    align: 'center',
    padding: 'default',
    sortDirection: false
  }, props.buttonHeaderName) : ""));
}

const useToolbarStyles = makeStyles(theme => ({
  root: {
    paddingLeft: theme.spacing(2),
    paddingRight: theme.spacing(1),
    marginTop: '20'
  },
  highlight: theme.palette.type === 'light' ? {
    color: theme.palette.secondary.main,
    backgroundColor: lighten(theme.palette.secondary.light, 0.85)
  } : {
    color: theme.palette.text.primary,
    backgroundColor: theme.palette.secondary.dark
  },
  title: {
    flex: '1 1 100%',
    position: 'absolute'
  }
}));

const EnhancedTableToolbar = props => {
  const classes = useToolbarStyles();
  const {
    numSelected,
    pageName
  } = props;
  return /*#__PURE__*/React.createElement(Toolbar, {
    className: clsx(classes.root, {
      [classes.highlight]: numSelected > 0
    })
  }, numSelected > 0 ? /*#__PURE__*/React.createElement(Typography, {
    className: classes.title,
    color: "inherit",
    variant: "subtitle1"
  }, numSelected, " selected") : /*#__PURE__*/React.createElement(Typography, {
    className: classes.title,
    variant: "h6",
    id: "tableTitle"
  }, pageName));
};

EnhancedTableToolbar.propTypes = {
  numSelected: PropTypes.number.isRequired
};
const useStyles = makeStyles(theme => ({
  root: {
    width: '100%'
  },
  paper: {
    // width: '98%',
    marginTop: theme.spacing(2),
    marginBottom: theme.spacing(2)
  },
  table: {
    minWidth: 750,
    borderTopWidth: 0,
    marginTop: 10
  },
  visuallyHidden: {
    border: 0,
    clip: 'rect(0 0 0 0)',
    height: 1,
    margin: -1,
    overflow: 'hidden',
    padding: 0,
    position: 'absolute',
    top: 20,
    width: 1
  }
}));
export default function EnhancedTable(props) {
  const classes = useStyles();
  const [order, setOrder] = React.useState('asc');
  const [orderBy, setOrderBy] = React.useState('calories');
  const [selected] = React.useState([]);
  const [page, setPage] = React.useState(0);
  const [dense] = React.useState(false);
  const [rowsPerPage, setRowsPerPage] = React.useState(5);

  const handleRequestSort = (event, property) => {
    const isAsc = orderBy === property && order === 'asc';
    setOrder(isAsc ? 'desc' : 'asc');
    setOrderBy(property);
  };

  const handleChangePage = (event, newPage) => {
    setPage(newPage);
  };

  const handleChangeRowsPerPage = event => {
    setRowsPerPage(parseInt(event.target.value, 10));
    setPage(0);
  };

  const isSelected = name => selected.indexOf(name) !== -1;

  const emptyRows = rowsPerPage - Math.min(rowsPerPage, 10 - page * rowsPerPage);

  function viewClick(rowData) {
    var index;
    console.log("print row data", rowData, "rowvalues", props.rowValues);

    if (rowData.hasOwnProperty("KrookiNumber")) {
      console.log("1", rowData);
      index = props.rowValues.findIndex(x => x.KrookiNumber === rowData.KrookiNumber);
    } else if (rowData.hasOwnProperty("OwnerUniqueID")) {
      console.log("2", rowData);
      index = props.rowValues.findIndex(x => x.OwnerUniqueID === rowData.OwnerUniqueID);
    } else if (rowData.hasOwnProperty("InvolvedPartyUniqueID")) {
      console.log("2", rowData);
      index = props.rowValues.findIndex(x => x.InvolvedPartyUniqueID === rowData.InvolvedPartyUniqueID);
    } else {
      console.log("3", rowData);
      index = props.rowValues.findIndex(x => x.DocumentNumber === rowData.DocumentNumber);
    }

    console.log("props.rowValues[index]", props.rowValues[index]);
    console.log("indexval", index);
    props.handleOnViewBtnClick(props.rowValues[index]);
  }

  function handleDelete(rowData) {
    var index;

    if (rowData.hasOwnProperty("KrookiNumber")) {
      index = props.rowValues.findIndex(x => x.KrookiNumber === rowData.KrookiNumber);
    } else if (rowData.hasOwnProperty("OwnerUniqueID")) {
      index = props.rowValues.findIndex(x => x.OwnerUniqueID === rowData.OwnerUniqueID);
    } else if (rowData.hasOwnProperty("InvolvedPartyUniqueID")) {
      index = props.rowValues.findIndex(x => x.InvolvedPartyUniqueID === rowData.InvolvedPartyUniqueID);
    } else {
      index = props.rowValues.findIndex(x => x.DocumentNumber === rowData.DocumentNumber);
    }

    props.handleOnDeleteBtnClick(props.rowValues[index], index);
  }

  console.log("props>>>", props);
  var filteredValues = [];
  props.rowValues.forEach(function (value) {
    var object = {};
    props.filterColumns.forEach(function (item) {
      if (value.hasOwnProperty(item)) {
        object[item] = value[item];
      } else {
        object[item] = "N/A";
      }
    });
    filteredValues.push(object);
  });
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("h4", {
    className: "rem15FontSize",
    style: props.lang === props.langCheckValue ? {
      float: "right"
    } : {
      float: "left"
    }
  }, props.tableName), /*#__PURE__*/React.createElement("div", {
    className: classes.root + " dyna-table-view"
  }, /*#__PURE__*/React.createElement(Paper, {
    className: classes.paper
  }, /*#__PURE__*/React.createElement(TableContainer, null, /*#__PURE__*/React.createElement(Table, {
    className: classes.table,
    "aria-labelledby": "tableTitle",
    size: dense ? 'small' : 'medium',
    "aria-label": "enhanced table" // stickyHeader aria-label="sticky table"

  }, /*#__PURE__*/React.createElement(EnhancedTableHead // classes={classes + "tabHeader"}
  , {
    classes: classes,
    numSelected: selected.length,
    order: order,
    orderBy: orderBy,
    onRequestSort: handleRequestSort,
    rowCount: props.rowValues.length,
    rowHeader: props.rowHeader,
    filterColumns: props.filterColumns,
    pageName: props.pageName,
    viewEnable: props.viewEnable,
    deleteEnable: props.deleteEnable,
    buttonHeaderName: props.buttonHeaderName
  }), /*#__PURE__*/React.createElement(TableBody, null, stableSort(filteredValues, getSorting(order, orderBy)).slice(page * rowsPerPage, page * rowsPerPage + rowsPerPage).map((row, index) => {
    const isItemSelected = isSelected(row.name); // const labelId = `enhanced-table-checkbox-${index}`;

    return /*#__PURE__*/React.createElement(TableRow, {
      hover: true,
      role: "checkbox",
      "aria-checked": isItemSelected,
      tabIndex: -1,
      key: row.ApplicationID + index,
      selected: isItemSelected
    }, Object.values(row).map(function (key, value) {
      return /*#__PURE__*/React.createElement(TableCell, {
        key: key + value,
        align: "center"
      }, key !== "" ? key : "N/A");
    }), /*#__PURE__*/React.createElement(TableCell, {
      align: "center",
      style: {
        display: props.deleteEnable === true || props.viewEnable ? "block" : "none"
      }
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: () => {
        viewClick(row);
      },
      className: props.viewEnable ? "viewEnablebtn-primary" : "viewDisablebtn-primary"
    }, props.viewBtnName), /*#__PURE__*/React.createElement("span", {
      style: {
        margin: "6px"
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: () => {
        handleDelete(row);
      },
      className: props.deleteEnable ? "deleteEnablebtn-primary" : "deleteDisablebtn-primary"
    }, props.deleteBtnName)));
  }), emptyRows > 0 && /*#__PURE__*/React.createElement(TableRow, {
    style: {
      height: (dense ? 33 : 53) * emptyRows
    }
  }, /*#__PURE__*/React.createElement(TableCell, {
    colSpan: 6
  }))))), /*#__PURE__*/React.createElement(TablePagination, {
    style: {
      display: props.enablePagination
    },
    rowsPerPageOptions: [5, 10, 25],
    component: "div",
    labelDisplayedRows: ({
      from,
      to,
      count
    }) => {
      return '' + from + '-' + to + " " + "of" + " " + count;
    },
    count: props.rowValues.length,
    labelRowsPerPage: "Rows per page",
    rowsPerPage: rowsPerPage,
    page: page,
    onChangePage: handleChangePage,
    onChangeRowsPerPage: handleChangeRowsPerPage
  }))));
}
EnhancedTableHead.propTypes = {
  classes: PropTypes.object.isRequired,
  numSelected: PropTypes.number.isRequired,
  onRequestSort: PropTypes.func.isRequired,
  order: PropTypes.oneOf(['asc', 'desc']).isRequired,
  orderBy: PropTypes.string.isRequired,
  rowCount: PropTypes.number.isRequired
};